pub struct Behavior {
pub common: CommonProperties,
pub name: Behavior,
pub description: Option<String>,
pub timestamp: Option<DateTime<Utc>>,
pub attributes: Option<HashMap<String, Value>>,
pub action_refs: Vec<String>,
pub technique_refs: Vec<ExternalReference>,
}Expand description
MAEC Behavior
A Behavior corresponds to the specific purpose behind a particular snippet of code, as executed by a malware instance. Examples include keylogging, detecting a virtual machine, and installing a backdoor.
Fields
common: CommonPropertiesCommon MAEC properties
name: BehaviorName of the behavior
description: Option<String>Textual description
timestamp: Option<DateTime<Utc>>Timestamp when the behavior occurred/was observed
attributes: Option<HashMap<String, Value>>Behavior attributes as key/value pairs
action_refs: Vec<String>References to actions implementing this behavior
technique_refs: Vec<ExternalReference>References to techniques used (ATT&CK, etc.)
Implementations